@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2000
 ;;;;
-;;;; $Id: base-class.lisp 7061 2003-09-07 06:34:45Z kevin $
+;;;; $Id$
 ;;;;
 ;;;; This file is Copyright (c) 2000-2003 by Kevin M. Rosenberg
 ;;;; *************************************************************************
@@ -20,8 +20,8 @@
   (:metaclass hyperobject-class)
   (:description "Basic hyperobject class"))
 
-(defmethod print-object ((obj hyperobject) (s stream))
+(defmethod print-object ((obj hyperobject) s)
   (print-unreadable-object (obj s :type t :identity nil)
     (funcall (obj-data-printer (get-view-id obj :compact-text))
-	     obj s nil)))
+             obj s nil)))
 
