@@ -114,11 +114,11 @@
 (rem-all-tests)
 
 (deftest :p1 (view-to-string mary :vid :compact-text) "Person:
-  Mary Jackson Thu, 4 May 2000 03:02:01 Style & Grace
+  Mary Jackson Thu 4 May 2000 03:02:01 Style & Grace
 ")
 
 (deftest :p2 (view-to-string mary :subobjects t :vid :compact-text) "Person:
-  Mary Jackson Thu, 4 May 2000 03:02:01 Style & Grace
+  Mary Jackson Thu 4 May 2000 03:02:01 Style & Grace
   Addresses:
     Home 321 Shady Lane 10
     Phone Numbers:
@@ -133,12 +133,12 @@
 
 (deftest :p3 (view-to-string mary :vid :compact-text-labels)
   "Person:
-  first-name Mary last-name Jackson dob Thu, 4 May 2000 03:02:01 resume Style & Grace
+  first-name Mary last-name Jackson dob Thu 4 May 2000 03:02:01 resume Style & Grace
 ")
 
 (deftest :p4 (view-to-string mary :vid :compact-text)
 "Person:
-  Mary Jackson Thu, 4 May 2000 03:02:01 Style & Grace
+  Mary Jackson Thu 4 May 2000 03:02:01 Style & Grace
 ")
 
 (deftest :cv1 (years-at-address home)
